@@ -1,10 +1,14 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
+import copy
 from unittest import TestCase
+
 from fabric.api import env
-from mock import patch, call, Mock
-from pydiploy.require.nginx import root_web, nginx_pkg, nginx_reload, web_static_files, web_configuration
+from mock import call, Mock, patch
+from pydiploy.require.nginx import (nginx_pkg, nginx_reload, nginx_restart,
+                                    root_web, web_configuration,
+                                    web_static_files)
 
 
 class NginxCheck(TestCase):
@@ -14,6 +18,7 @@ class NginxCheck(TestCase):
     """
 
     def setUp(self):
+        self.previous_env = copy.deepcopy(env)
         env.remote_static_root = "remote_static_root"
         env.local_tmp_dir = 'local_tmp_dir'
         env.server_name = "server_name"
@@ -22,6 +27,7 @@ class NginxCheck(TestCase):
 
     def tearDown(self):
         env.clear()
+        env.update(self.previous_env)
 
     @patch('fabtools.require.files.directory', return_value=Mock())
     def test_root_web(self, files_directory):
@@ -53,7 +59,28 @@ class NginxCheck(TestCase):
 
         nginx_reload()
 
+        self.assertTrue(is_running.called)
         self.assertFalse(reload.called)
+        self.assertTrue(start.called)
+        self.assertEqual(start.call_args, call('nginx'))
+
+    @patch('fabtools.service.is_running', return_value=True)
+    @patch('fabtools.service.start', return_value=Mock())
+    @patch('fabtools.service.restart', return_value=Mock())
+    def test_nginx_restart(self, restart, start, is_running):
+        nginx_restart()
+        self.assertTrue(is_running.called)
+        self.assertFalse(start.called)
+        self.assertTrue(restart.called)
+
+        is_running.return_value = False
+        restart.called = False
+        is_running.called = False
+        start.called = False
+
+        nginx_restart()
+
+        self.assertFalse(restart.called)
         self.assertTrue(is_running.called)
         self.assertTrue(start.called)
         self.assertEqual(start.call_args, call('nginx'))
